@@ -1,15 +1,13 @@
 """
 toppy
 ~~~~~~
-A simple API wrapper for Top.gg and Discord Bot List
-in Python with many simple yet powerful features.
+An API wrapper made for discord.py or any forks for Discord Bot List and/or Top.gg
 
 :copyright: (c) 2022-present The Master and chawkk6404
 :license: MIT
 """
 
-from .client import Client
-from .dbl import DBLClient
+from .client import Client, DBLClient, TopGGClient
 from .errors import (
     BadRequest,
     ClientNotReady,
@@ -20,15 +18,15 @@ from .errors import (
     RateLimited,
     Unauthorized
 )
-from .topgg import TopGGClient
-from .webhook import create_webhook_server, DiscordBotListVotePayload, TopGGVotePayload
+
+from . import http, utils, protocols, cog, models
 
 
 __all__ = (
     # client.py
     'Client',
-    # dbl.py
     'DBLClient',
+    'TopGGClient',
     # errors
     'BadRequest',
     'ClientNotReady',
@@ -37,13 +35,7 @@ __all__ = (
     'HTTPException',
     'NoTokenSet',
     'RateLimited',
-    'Unauthorized',
-    # topgg.py
-    'TopGGClient',
-    # webhook.py
-    'create_webhook_server',
-    'DiscordBotListVotePayload',
-    'TopGGVotePayload'
+    'Unauthorized'
 )
 
 
@@ -51,4 +43,4 @@ __title__ = 'toppy'
 __authors__ = ('The Master', 'chawkk6404')
 __license__ = 'MIT'
 __copyright__ = '2022-present The Master and chawkk6404'
-__version__ = '1.4.1'
+__version__ = '1.5.0'
