@@ -16,9 +16,7 @@ except IndexError:
 discord: Any = importlib.import_module(lib)
 commands: Any = importlib.import_module(f'{lib}.ext.commands')
 
-from .client import Client
-from .dbl import DBLClient
-from .topgg import TopGGClient
+from .client import Client, DBLClient, TopGGClient
 from .errors import NoTokenSet
 
 if TYPE_CHECKING:
@@ -29,7 +27,7 @@ if SPHINX:
 
 
 __all__ = (
-    'ToppyCog'
+    'ToppyCog',
 )
 
 
@@ -60,6 +58,9 @@ class ToppyCog(commands.Cog):
     @commands.Cog.listener('on_topgg_post_error')
     @commands.Cog.listener('on_dbl_post_error')
     async def post_error(self, error: aiohttp.ClientResponseError):
+        """
+        This listener will print ``on_topgg_post_error`` and ``on_dbl_post_error`` to the console.
+        """
         print(f'{__name__}: An error occured when posting stats | Status code: {error.status}.'
               f' Enable logging for more information.')
 
